{ pkgs, ... }: 
{
  networking.hostName = "katzen-cafe";

  networking.networkmanager.enable = true;
  networking.firewall = {
    allowedTCPPorts = [ 22 80 443 ];
  };

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.kernelPackages = pkgs.linuxPackages_latest;
  boot.kernelParams = [ "console=tty" ];
  boot.initrd.kernelModules = [ "virtio_gpu" ];

  users.users.april = {
    isNormalUser = true;
    packages = with pkgs; [ podman ];
    createHome = true;
  };

  services.openssh = {
    enable = true;
    permitRootLogin = "prohibit-password";
  };

  environment.systemPackages = with pkgs; [
    vim wget neofetch btop
  ];

  fileSystems."/" = { 
    device = "/dev/sda1";
    fsType = "ext4";
  };

  fileSystems."/boot" = { 
    device = "/dev/sda3";
    fsType = "vfat";
  };

  swapDevices = [ { 
    device = "/dev/sda2"; 
  } ];
}
